@@ -19,6 +19,8 @@ extend_axis = function(lim, eps = 0.02) lim + c(-1, 1) * diff(lim) * eps
 #' @importFrom grDevices xy.coords
 #' @rdname plot.prettyB
 #' @export
+#' @examples
+#' plot_p(1:10, 1:10)
 plot.prettyB = function(x, y = NULL, type = "p", xlim = NULL, ylim = NULL,
                         log = "", main = NULL, sub = NULL,
                         xlab = NULL, ylab = NULL,
@@ -38,40 +40,61 @@ plot.prettyB = function(x, y = NULL, type = "p", xlim = NULL, ylim = NULL,
   # op = set_par_minimal()
   # on.exit(par(op))
 
+  if (is.matrix(x)) {
+    if (ncol(x) > 1 && !is.null(y)) {
+      stop("x and y have different lengths (x is a matrix)", call. = FALSE)
+    }
+    if (ncol(x) > 1) {
+      y = x[, 2]
+    }
+    x = x[, 1]
+  }
+
   ## Do we have a y?
   if (is.null(y)) {
-    x_tmp = 1:length(x)
+    x_tmp = seq_len(NROW(x)) # Handles the vector and matrix case
     y_tmp = x
   } else {
     x_tmp = x
     y_tmp = y
   }
-
+  #xlim = c(1e1, 120)
   ## Now check for log scales
-  if (is.null(xlim) && is_x(log)) {
-    xlim = extend_axis(range(x_tmp))
-  }
+  #if (is.null(xlim) && is_x(log)) {
+  #  xlim = extend_axis(range(x_tmp))
+  #}
 
-  if (is.null(xlim)) {
+  if (is.null(xlim) && !is_x(log)) {
     ticks_x = pretty(x_tmp)
     xlim = extend_axis(range(ticks_x))
-  } else {
-    ticks_x = pretty(c(xlim, x_tmp))
+  } else if (!is_x(log)) {
+    ticks_x = pretty(xlim)
     xlim = range(ticks_x)
-  }
-
+  } else if (is_x(log) && is.null(xlim)) {
+    ticks_x = 10 ^ pretty(log10(x_tmp))
+    xlim = range(ticks_x)
+  } #else  {
+    #ticks_x = 10^pretty(log10(xlim))
+    #xlim = range(ticks_x)
+  #}
   ## Now check for log scales
-  if (is.null(ylim) && is_y(log)) {
-    ylim = extend_axis(range(y_tmp))
-  }
+  #if (is.null(ylim) && is_y(log)) {
+  #  ylim = extend_axis(range(y_tmp))
+  #}
 
-  if (is.null(ylim)) {
+  if (is.null(ylim) && !is_y(log)) {
     ticks_y = pretty(y_tmp)
     ylim = extend_axis(range(ticks_y))
-  } else {
-    ticks_y = pretty(c(ylim, y_tmp))
+  } else if (!is_y(log)) {
+    ticks_y = pretty(ylim)
     ylim = range(ticks_y)
-  }
+  } else if (is_y(log) && is.null(ylim)) {
+    ticks_y = 10 ^ pretty(log10(y_tmp))
+    ylim = range(ticks_y)
+  } #else  {
+#    ticks_y = 10^pretty(log10(ylim))
+#    ylim = range(ticks_y)
+#  }
 
   # Unchanged Arguments
   args = list(...)
@@ -92,25 +115,38 @@ plot.prettyB = function(x, y = NULL, type = "p", xlim = NULL, ylim = NULL,
   args$main = NULL
   args$sub = NULL
   args$axes = FALSE
-  args$panel.first = substitute(grid_lines_h(ticks_y))
+
+  ## Log scales are a pain; pretty doesn't work
+  if (!(is_y(log) && !is.null(ylim))) {
+    args$panel.first = substitute(grid_lines_h(ticks_y))
+  }
 
   if (is.null(args$pch)) args$pch = 21
   if (is.null(args$bg)) args$bg = 1
 
   # Call to default plot
   do.call(graphics::plot.default, args)
-
+  message(args$xaxt)
   ## Now add in tick marks and labels
+
   if (is_x(log)) {
     ticks_x = axTicks(1)
   }
+  if (is.null(args$xaxt) || args$xaxt != "n") {
+    add_x_axis(ticks_x)
+  }
   if (is_y(log)) {
     ticks_y = axTicks(2)
   }
+  if (is.null(args$yaxt) || args$yaxt != "n") {
 
+    add_y_axis(ticks_y, tick = FALSE)
+  }
+
+  if (is_y(log) && !is.null(ylim)) {
+    grid_lines_h(ticks_y)
+  }
   # Add axis & title
-  add_x_axis(ticks_x)
-  add_y_axis(ticks_y, tick = FALSE)
   add_title(main)
   add_sub(sub)
   invisible(NULL)
