@@ -1,6 +1,6 @@
 library("testthat")
-library("vdiffr")
+
 test_check("prettyB")
 
 # To rerun tests
-# vdiffr::manage_cases()
+# manage_cases()
