@@ -1,12 +1,16 @@
 test_that("Testing barplot", {
   context("Barplot")
   testthat::skip_on_travis()
-  vdiffr::expect_doppelganger("barplot basic",
+  testthat::skip_on_ci()
+  testthat::skip_on_cran()
+  expect_doppelganger("barplot basic",
                               barplot_p(VADeaths))
-  vdiffr::expect_doppelganger("barplot horiz",
+  expect_doppelganger("barplot horiz",
                               barplot_p(VADeaths, horiz = TRUE))
-  vdiffr::expect_doppelganger("barplot labels",
+  expect_doppelganger("barplot labels",
                               barplot_p(VADeaths, xlab = "X", ylab = "Y",
                                       main = "Main", sub = "Sub"))
 
+  expect_doppelganger("barplot basic no axisnames",
+                      barplot_p(VADeaths, axisnames = FALSE))
 })
